data = {
    "cancelled_jobs": 0,
    "comments": "https://example.com/api/v1/3/comments/",
    "created_jobs": 0,
    "creation_date": "2021-07-09T00:02:20.005324-04:00",
    "creator_username": "mock_username",
    "errored_jobs": 0,
    "files": "https://example.com/api/v1/3/files/",
    "finished_jobs": 4,
    "id": 3,
    "modification_date": "2021-07-09T00:02:20.005357-04:00",
    "name": "A mock feed",
    "note": "https://example.com/api/v1/note3/",
    "owner": [
        "https://example.com/api/v1/users/4/"
    ],
    "plugin_instances": "https://example.com/api/v1/3/plugininstances/",
    "registering_jobs": 0,
    "scheduled_jobs": 0,
    "started_jobs": 0,
    "taggings": "https://example.com/api/v1/3/taggings/",
    "tags": "https://example.com/api/v1/3/tags/",
    "template": {
        "data": [
            {
                "name": "name",
                "value": ""
            },
            {
                "name": "owner",
                "value": ""
            }
        ]
    },
    "url": "https://example.com/api/v1/3/",
    "waiting_jobs": 0
}
